# eric7.MicroPython.Devices.EspDialogs.EspFirmwareSelectionDialog

Module implementing a dialog to select the ESP chip type and the firmware to be flashed.

### Global Attributes

None

### Classes

EspFirmwareSelectionDialog | Class implementing a dialog to select the ESP chip type and the firmware to be flashed.

### Functions

None

## EspFirmwareSelectionDialog

Class implementing a dialog to select the ESP chip type and the firmware to be flashed.

### Derived from

QDialog, Ui_EspFirmwareSelectionDialog

### Class Attributes

Chips
FlashAddresses
FlashModes

### Class Methods

None

### Methods

EspFirmwareSelectionDialog | Constructor
__updateOkButton | Private method to update the state of the OK button.
getData | Public method to get the entered data.
on_addressEdit_textChanged | Private slot handling a change of the address.
on_espComboBox_currentTextChanged | Private slot to handle the selection of a chip type.
on_firmwarePicker_textChanged | Private slot handling a change of the firmware path.

### Static Methods

None

#### EspFirmwareSelectionDialog (Constructor)

EspFirmwareSelectionDialog(addon=False, parent=None)

Constructor

addon (bool)
  flag indicating an addon firmware
parent (QWidget)
  reference to the parent widget

#### EspFirmwareSelectionDialog.__updateOkButton

__updateOkButton()

Private method to update the state of the OK button.

#### EspFirmwareSelectionDialog.getData

getData()

Public method to get the entered data.

Return:
  tuple containing the selected chip type, the path of the firmware file, the baud rate, the flash mode and the flash address

Return Type:
  tuple of (str, str, str, str, str)

#### EspFirmwareSelectionDialog.on_addressEdit_textChanged

on_addressEdit_textChanged(address)

Private slot handling a change of the address.

address (str)
  entered address

#### EspFirmwareSelectionDialog.on_espComboBox_currentTextChanged

on_espComboBox_currentTextChanged(chip)

Private slot to handle the selection of a chip type.

chip (str)
  selected chip type

#### EspFirmwareSelectionDialog.on_firmwarePicker_textChanged

on_firmwarePicker_textChanged(firmware)

Private slot handling a change of the firmware path.

firmware (str)
  path to the firmware

Up